This repository contains the code for the Battlehack20 minimalengine.

## Installation and Usage

### Installation
To install, run
```bash
$ pip install battlehack20-minimalengine
```
You may need to first run
```bash
$ pip uninstall battlehack20
```
Most things should be able to be run the same as with the original `battlehack20`,
but much faster and without a sandbox.
